summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xhal/nv_hal/src/nv_hal.cpp2
-rwxr-xr-xservice/native/backup_manager/server/Makefile2
-rwxr-xr-xservice/native/framework_unified/client/Makefile2
-rwxr-xr-xservice/native/framework_unified/client/NS_Logger/src/ns_logger.cpp2
-rwxr-xr-xservice/native/framework_unified/client/include/native_service/ns_logger_if.h6
-rwxr-xr-xservice/native/framework_unified/client/include/native_service/ns_np_types.h4
-rwxr-xr-xservice/native/notification_persistent_service/server/include/ns_npp_types.h2
-rwxr-xr-xservice/system/interface_unified/scfg/ss_logger.cfg4
-rwxr-xr-xservice/system/logger_service/server/Makefile2
-rwxr-xr-xservice/system/logger_service/server/include/ss_logger_common.h2
-rwxr-xr-xservice/system/logger_service/server/include/ss_logger_scrshot.h6
-rwxr-xr-xservice/system/logger_service/server/src/ss_logger_error_event_cfg.cpp4
-rwxr-xr-xservice/system/logger_service/server/src/ss_logger_error_event_responses.cpp4
-rwxr-xr-xservice/system/logger_service/server/src/ss_logger_util.cpp4
-rwxr-xr-xservice/system/rom_access_library/library/include/system_service/ss_sm_ram_access.h8
-rwxr-xr-xservice/system/rom_access_library/library/rom/src/ss_sm_ram_access.cpp2
-rwxr-xr-xservice/system/rom_access_library/library/rom/src/ss_sm_rom_access.cpp2
-rwxr-xr-xservice/system/system_manager/server/Makefile2
-rwxr-xr-xservice/system/system_manager/server/src/ss_system_manager.cpp2
-rwxr-xr-xservice/system/system_manager/server/src/ss_system_manager_callbacks.cpp2
-rwxr-xr-xservice/vehicle/positioning/server/src/Sensor/Makefile2
-rwxr-xr-xservice/vehicle/positioning/server/src/Sensor/SensorLog.cpp2
-rwxr-xr-xservice/vehicle/positioning_base_library/library/Makefile2
-rwxr-xr-xservice/vehicle/positioning_base_library/library/src/_pbOSCtrl.cpp4
24 files changed, 37 insertions, 37 deletions
diff --git a/hal/nv_hal/src/nv_hal.cpp b/hal/nv_hal/src/nv_hal.cpp
index 718b951..6011e0b 100755
--- a/hal/nv_hal/src/nv_hal.cpp
+++ b/hal/nv_hal/src/nv_hal.cpp
@@ -31,7 +31,7 @@
const char *kMediaType[NVHALMEDIA_MAX] = {
"/tmp/bkup/",
"/var/local/lib/basesystem/ramd/BS/ns/backup_manager/rwdata/",
- "/nv/BS/ns/backup_manager/rwdata/",
+ "/var/local/lib/basesystem/ns/backup_manager/rwdata/",
};
const int kMaxPath = 127; // Max length of path
diff --git a/service/native/backup_manager/server/Makefile b/service/native/backup_manager/server/Makefile
index 7f9fa39..3e54063 100755
--- a/service/native/backup_manager/server/Makefile
+++ b/service/native/backup_manager/server/Makefile
@@ -62,6 +62,6 @@ CPPFLAGS += -DIMPL_AGL_APPLICATION_CALLBACKS_PRE_BACKGROUND
install-data: install_data
install_data:
- install -d -m 755 $(DESTDIR)/nv/BS/ns/backup_manager/rwdata
+ install -d -m 755 $(DESTDIR)/var/local/lib/basesystem/ns/backup_manager/rwdata
include ../../native_service.mk
diff --git a/service/native/framework_unified/client/Makefile b/service/native/framework_unified/client/Makefile
index 099b7b9..53d5075 100755
--- a/service/native/framework_unified/client/Makefile
+++ b/service/native/framework_unified/client/Makefile
@@ -260,7 +260,7 @@ SUBDIRS := NS_XMLConfigeParser NS_Utility
all:
install-data:install_cfg
- install -d -m 775 $(DESTDIR)/nv/BS/ns/framework_unified/rwdata
+ install -d -m 775 $(DESTDIR)/var/local/lib/basesystem/ns/framework_unified/rwdata
install_cfg:
install -d -m 775 $(DESTDIR)/etc/basesystem/ns/framework_unified/rodata
diff --git a/service/native/framework_unified/client/NS_Logger/src/ns_logger.cpp b/service/native/framework_unified/client/NS_Logger/src/ns_logger.cpp
index 3ae00b6..974e799 100755
--- a/service/native/framework_unified/client/NS_Logger/src/ns_logger.cpp
+++ b/service/native/framework_unified/client/NS_Logger/src/ns_logger.cpp
@@ -110,7 +110,7 @@ FRAMEWORKUNIFIEDLOGSYSEVENTPARAM g_FrameworkunifiedLogSysEventParams = {FALSE};
#define FRAMEWORKUNIFIEDLOG_CONFIG__CWORD84__TMP "ns_logger_frameworkunifiedlog__CWORD84_.tmp"
#define FRAMEWORKUNIFIEDLOG_CONFIG__CWORD84__NV "ns_logger_frameworkunifiedlog__CWORD84_.cfg"
-#define FRAMEWORKUNIFIEDLOG_CONFIG_NV "/nv/BS/ns/framework_unified/rwdata/"
+#define FRAMEWORKUNIFIEDLOG_CONFIG_NV "/var/local/lib/basesystem/ns/framework_unified/rwdata/"
#define FRAMEWORKUNIFIEDLOG_CONFIG_TMP_NV "ns_logger_frameworkunifiedlog_tmp.cfg"
#ifndef TN_LOGGERRTIME
diff --git a/service/native/framework_unified/client/include/native_service/ns_logger_if.h b/service/native/framework_unified/client/include/native_service/ns_logger_if.h
index e67c543..33d9266 100755
--- a/service/native/framework_unified/client/include/native_service/ns_logger_if.h
+++ b/service/native/framework_unified/client/include/native_service/ns_logger_if.h
@@ -761,9 +761,9 @@ EFrameworkunifiedStatus NsLogGetFrameworkunifiedLogFlag(UI_8 flag_id, UI_8 *mode
/// \~english @par Detail
/// set the real-time log output using the setting value.\n
/// need to reboot during ROM start in order to switch to Ethernet output\n
-/// /nv/BS/ns/framework_unified/rwdata/frameworkunifiedlog.ether file will be generated
-/// when mode FRAMEWORKUNIFIEDLOG_REALTIMELOG_MODE_ETHER /nv/BS/ns/framework_unified/rwdata/frameworkunifiedlog.ether\n
-/// and /nv/BS/ns/framework_unified/rwdata/frameworkunifiedlog.ether file will be delated when mode is not FRAMEWORKUNIFIEDLOG_REALTIMELOG_MODE_ETHER
+/// /var/local/lib/basesystem/ns/framework_unified/rwdata/frameworkunifiedlog.ether file will be generated
+/// when mode FRAMEWORKUNIFIEDLOG_REALTIMELOG_MODE_ETHER /var/local/lib/basesystem/ns/framework_unified/rwdata/frameworkunifiedlog.ether\n
+/// and /var/local/lib/basesystem/ns/framework_unified/rwdata/frameworkunifiedlog.ether file will be delated when mode is not FRAMEWORKUNIFIEDLOG_REALTIMELOG_MODE_ETHER
/// \~english @par Classification
/// Public
/// \~english @par Type
diff --git a/service/native/framework_unified/client/include/native_service/ns_np_types.h b/service/native/framework_unified/client/include/native_service/ns_np_types.h
index 01559d9..85e0a3e 100755
--- a/service/native/framework_unified/client/include/native_service/ns_np_types.h
+++ b/service/native/framework_unified/client/include/native_service/ns_np_types.h
@@ -25,10 +25,10 @@
#define FRAMEWORK_UNIFIED_CLIENT_NS_NPSERVICEIF_INCLUDE_NS_NP_TYPES_H_
// Path of immediate notification data in NS_NPS version 1
-#define IMMEDIATE_PERSISTENCE_STORAGE_V1 "/nv/BS/ns/npp/rwdata/NPSNOR/"
+#define IMMEDIATE_PERSISTENCE_STORAGE_V1 "/var/local/lib/basesystem/ns/npp/rwdata/NPSNOR/"
// Path of immediate notification data in NS_NPS version 2
-#define IMMEDIATE_PERSISTENCE_STORAGE_V2 "/nv/BS/ns/npp/rwdata/"
+#define IMMEDIATE_PERSISTENCE_STORAGE_V2 "/var/local/lib/basesystem/ns/npp/rwdata/"
// name of persistence folder for persistent type categorization
#define USERDATADIR "UserData/" // stores all the user data (all user common data as well as user specific data)
diff --git a/service/native/notification_persistent_service/server/include/ns_npp_types.h b/service/native/notification_persistent_service/server/include/ns_npp_types.h
index 79a44d7..5e6573b 100755
--- a/service/native/notification_persistent_service/server/include/ns_npp_types.h
+++ b/service/native/notification_persistent_service/server/include/ns_npp_types.h
@@ -55,7 +55,7 @@
// name of NSNPS version file
#define VERSION_TXT "version.txt"
-#define STORAGE_PATH "/nv/BS/ns/npp/rwdata/"
+#define STORAGE_PATH "/var/local/lib/basesystem/ns/npp/rwdata/"
typedef enum ENPSLoadType {
diff --git a/service/system/interface_unified/scfg/ss_logger.cfg b/service/system/interface_unified/scfg/ss_logger.cfg
index 8cfa13d..8e79455 100755
--- a/service/system/interface_unified/scfg/ss_logger.cfg
+++ b/service/system/interface_unified/scfg/ss_logger.cfg
@@ -1,8 +1,8 @@
[LOGGING]
LogMaxFileSize=5242880
PerformanceLogSize=262144
-EmmcOutputPath=/nv/BS/ss/logger_service/rwdata/frameworkunifiedlog
-EmmcOutputNaviLogPath=/nv/BS/ss/logger_service/rwdata/log2/awlog
+EmmcOutputPath=/var/local/lib/basesystem/ss/logger_service/rwdata/frameworkunifiedlog
+EmmcOutputNaviLogPath=/var/local/lib/basesystem/ss/logger_service/rwdata/log2/awlog
Usb0MountPath=/mnt/sda1
Usb1MountPath=/mnt/sdb1
SdMountPath=/fs/sd0
diff --git a/service/system/logger_service/server/Makefile b/service/system/logger_service/server/Makefile
index 5292a18..7614a25 100755
--- a/service/system/logger_service/server/Makefile
+++ b/service/system/logger_service/server/Makefile
@@ -23,6 +23,6 @@ all:
install-data:install_data
install_data:
- install -d -m 755 $(DESTDIR)/nv/BS/ss/logger_service/rwdata/frameworkunifiedlog
+ install -d -m 755 $(DESTDIR)/var/local/lib/basesystem/ss/logger_service/rwdata/frameworkunifiedlog
include ../../system_service.mk
diff --git a/service/system/logger_service/server/include/ss_logger_common.h b/service/system/logger_service/server/include/ss_logger_common.h
index 3d7c3d5..d158148 100755
--- a/service/system/logger_service/server/include/ss_logger_common.h
+++ b/service/system/logger_service/server/include/ss_logger_common.h
@@ -49,7 +49,7 @@ const CHAR KERNEL_BOOT_LOG_PATH_FN[] = "/var/local/lib/basesystem/ramd/BS/ss/log
const UI_32 PERFORMANCELOG_FILE_SZ = 256 * 1024;
-#define CLEAR_LOG_PATH_FN "/nv/BS/ss/logger_service/rwdata/frameworkunifiedlog/"
+#define CLEAR_LOG_PATH_FN "/var/local/lib/basesystem/ss/logger_service/rwdata/frameworkunifiedlog/"
#define NULLCHAR '\0'
#define DEBUG_USB_PATH "/mnt/sda1"
diff --git a/service/system/logger_service/server/include/ss_logger_scrshot.h b/service/system/logger_service/server/include/ss_logger_scrshot.h
index 3cd22a6..11f0bd6 100755
--- a/service/system/logger_service/server/include/ss_logger_scrshot.h
+++ b/service/system/logger_service/server/include/ss_logger_scrshot.h
@@ -22,9 +22,9 @@
#ifndef LOGGER_SERVICE_SERVER_INCLUDE_SS_LOGGER_SCRSHOT_H_
#define LOGGER_SERVICE_SERVER_INCLUDE_SS_LOGGER_SCRSHOT_H_
-#define JPEG_PATH_CH0 "/nv/BS/ss/logger_service/rwdata/screenShot/screen_shot_Ch0.jpeg"
-#define JPEG_PATH_CH1 "/nv/BS/ss/logger_service/rwdata/screenShot/screen_shot_Ch1.jpeg"
+#define JPEG_PATH_CH0 "/var/local/lib/basesystem/ss/logger_service/rwdata/screenShot/screen_shot_Ch0.jpeg"
+#define JPEG_PATH_CH1 "/var/local/lib/basesystem/ss/logger_service/rwdata/screenShot/screen_shot_Ch1.jpeg"
#define SCRSHOT_EXE_PATH "/usr/bin/SS_ScrShot"
-#define SCREEN_SHOT_PATH "/nv/BS/ss/logger_service/rwdata/screenShot"
+#define SCREEN_SHOT_PATH "/var/local/lib/basesystem/ss/logger_service/rwdata/screenShot"
#endif // LOGGER_SERVICE_SERVER_INCLUDE_SS_LOGGER_SCRSHOT_H_
diff --git a/service/system/logger_service/server/src/ss_logger_error_event_cfg.cpp b/service/system/logger_service/server/src/ss_logger_error_event_cfg.cpp
index dd12fa2..9575a7a 100755
--- a/service/system/logger_service/server/src/ss_logger_error_event_cfg.cpp
+++ b/service/system/logger_service/server/src/ss_logger_error_event_cfg.cpp
@@ -60,8 +60,8 @@ enum ARTIFACT_BIT {
//////////////////////////////////////////////////////////////////////////////////////////
///// Definition for Logging Artifact Filepaths
//////////////////////////////////////////////////////////////////////////////////////////
-const char LAF_DEBUG_FOLDER[] = "/nv/BS/ss/logger_service/rwdata";
-const char LAF_DEBUG_FOLDER2[] = "/nv/BS/ss/logger_service/rwdata/log2";
+const char LAF_DEBUG_FOLDER[] = "/var/local/lib/basesystem/ss/logger_service/rwdata";
+const char LAF_DEBUG_FOLDER2[] = "/var/local/lib/basesystem/ss/logger_service/rwdata/log2";
const char LAF_MONTECARLO_FN[] = "/tmp/MonteCarlo";
const char LAF_METACORE_FN[] = "/tmp/MetaCore";
const char LAF_CMS_FN[] = "/tmp/cms";
diff --git a/service/system/logger_service/server/src/ss_logger_error_event_responses.cpp b/service/system/logger_service/server/src/ss_logger_error_event_responses.cpp
index dc23d8b..52ca07b 100755
--- a/service/system/logger_service/server/src/ss_logger_error_event_responses.cpp
+++ b/service/system/logger_service/server/src/ss_logger_error_event_responses.cpp
@@ -429,7 +429,7 @@ EFrameworkunifiedStatus CErrorEvent::OnClearAllLogRequest(HANDLE f_hApp) {
clear_file_path.c_str());
}
- clear_file_path = "/nv/BS/ss/logger_service/rwdata/log2/awlog/";
+ clear_file_path = "/var/local/lib/basesystem/ss/logger_service/rwdata/log2/awlog/";
if (CFSDirectory::RemoveSubDirectory(clear_file_path)) {
FRAMEWORKUNIFIEDLOG(ZONE_INFO, __FUNCTION__,
"SS_Logger Clear %s directory delete successful.",
@@ -440,7 +440,7 @@ EFrameworkunifiedStatus CErrorEvent::OnClearAllLogRequest(HANDLE f_hApp) {
clear_file_path.c_str());
}
- clear_file_path = "/nv/BS/ss/logger_service/rwdata/log2/core/";
+ clear_file_path = "/var/local/lib/basesystem/ss/logger_service/rwdata/log2/core/";
if (CFSDirectory::RemoveSubDirectory(clear_file_path)) {
FRAMEWORKUNIFIEDLOG(ZONE_INFO, __FUNCTION__,
"SS_Logger Clear %s directory delete successful.",
diff --git a/service/system/rom_access_library/library/include/system_service/ss_sm_ram_access.h b/service/system/rom_access_library/library/include/system_service/ss_sm_ram_access.h
index f96966b..e0b512f 100755
--- a/service/system/rom_access_library/library/include/system_service/ss_sm_ram_access.h
+++ b/service/system/rom_access_library/library/include/system_service/ss_sm_ram_access.h
@@ -171,7 +171,7 @@ explicit RAM_AccessIf(RAM_WAKEUP_STATE wup_state = RAM_WAKEUP_STATE_DONT_CARE);
* - The change in the internal status does not occur by this API.
* \~english @par Conditions of processing failure
* - If p_boot_info is NULL [eFrameworkunifiedStatusFail]
- * - If read data from secondary storage area or /nv/BS/ss/rom_access_library/rwdata/ramdata.dat
+ * - If read data from secondary storage area or /var/local/lib/basesystem/ss/rom_access_library/rwdata/ramdata.dat
* failed [eFrameworkunifiedStatusFail]
* \~english @par Classification:
* Public
@@ -179,7 +179,7 @@ explicit RAM_AccessIf(RAM_WAKEUP_STATE wup_state = RAM_WAKEUP_STATE_DONT_CARE);
* Sync only(None communication)
* \~english @par Detail:
* Copy the system information stored in the secondary storage area or
- * in /nv/BS/ss/rom_access_library/rwdata/ramdata.dat to p_boot_info. \n
+ * in /var/local/lib/basesystem/ss/rom_access_library/rwdata/ramdata.dat to p_boot_info. \n
* \~english @see setRamInfo
*/
EFrameworkunifiedStatus getRamInfo(RAM_SM_INFO_t* p_boot_info);
@@ -214,7 +214,7 @@ explicit RAM_AccessIf(RAM_WAKEUP_STATE wup_state = RAM_WAKEUP_STATE_DONT_CARE);
* - The change in the internal status does not occur by this API.
* \~english @par Conditions of processing failure
* - If p_boot_info is NULL [eFrameworkunifiedStatusFail]
- * - If write data to secondary storage area or /nv/BS/ss/rom_access_library/rwdata/ramdata.dat
+ * - If write data to secondary storage area or /var/local/lib/basesystem/ss/rom_access_library/rwdata/ramdata.dat
* failed [eFrameworkunifiedStatusFail]
* \~english @par Classification:
* Public
@@ -222,7 +222,7 @@ explicit RAM_AccessIf(RAM_WAKEUP_STATE wup_state = RAM_WAKEUP_STATE_DONT_CARE);
* Sync only(None communication)
* \~english @par Detail:
* Write the system manegement information stored in p_boot_info to the
- * secondary storage area or /nv/BS/ss/rom_access_library/rwdata/ramdata.dat. \n
+ * secondary storage area or /var/local/lib/basesystem/ss/rom_access_library/rwdata/ramdata.dat. \n
* \~english @see getRamInfo
*/
EFrameworkunifiedStatus setRamInfo(RAM_SM_INFO_t* p_boot_info);
diff --git a/service/system/rom_access_library/library/rom/src/ss_sm_ram_access.cpp b/service/system/rom_access_library/library/rom/src/ss_sm_ram_access.cpp
index b5cf244..2cfe2a0 100755
--- a/service/system/rom_access_library/library/rom/src/ss_sm_ram_access.cpp
+++ b/service/system/rom_access_library/library/rom/src/ss_sm_ram_access.cpp
@@ -29,7 +29,7 @@
-#define RAM_PATH "/nv/BS/ss/rom_access_library/rwdata/ramdata.dat"
+#define RAM_PATH "/var/local/lib/basesystem/ss/rom_access_library/rwdata/ramdata.dat"
#define RAM_OLD_PATH RAM_PATH".old"
static const uint8_t kSigNature[] = { 0xDE, 0xAD, 0xBE, 0xEF };
static const uint8_t kMagic[] = { 0xDE, 0xAD, 0xBE, 0xEF };
diff --git a/service/system/rom_access_library/library/rom/src/ss_sm_rom_access.cpp b/service/system/rom_access_library/library/rom/src/ss_sm_rom_access.cpp
index 53589c2..8428814 100755
--- a/service/system/rom_access_library/library/rom/src/ss_sm_rom_access.cpp
+++ b/service/system/rom_access_library/library/rom/src/ss_sm_rom_access.cpp
@@ -38,7 +38,7 @@
#include "ss_sm_checksum.h"
#include "ss_rom_access_define.h"
-#define ROM_ACCESS_DIR "/nv/BS/ss/rom_access_library/rwdata"
+#define ROM_ACCESS_DIR "/var/local/lib/basesystem/ss/rom_access_library/rwdata"
#define ROM_ACCESS_FILE "romdata.dat"
const CHAR kDefaultRomDevice[] = ROM_ACCESS_DIR"/"ROM_ACCESS_FILE;
const CHAR kRecoveryRomDevice[] = ROM_ACCESS_DIR"/"ROM_ACCESS_FILE".old";
diff --git a/service/system/system_manager/server/Makefile b/service/system/system_manager/server/Makefile
index d2b514f..0b67bd4 100755
--- a/service/system/system_manager/server/Makefile
+++ b/service/system/system_manager/server/Makefile
@@ -110,7 +110,7 @@ install_data:
$(SDKTARGETSYSROOT)/usr/share/launch_xml2cfg.sh ./sm_launch.tmp.xml > ./sm_launch.cfg
install -d -m 755 $(DESTDIR)/etc/basesystem/ss/system_manager/rwdata
install -m 644 ./sm_launch.cfg $(DESTDIR)/etc/basesystem/ss/system_manager/rwdata
- install -d -m 755 $(DESTDIR)/nv/BS/ss/system_manager/rwdata
+ install -d -m 755 $(DESTDIR)/var/local/lib/basesystem/ss/system_manager/rwdata
install -d -m 755 $(DESTDIR)/usr/share/BS/ss/system_manager/rodata
install -m 644 ./version.txt $(DESTDIR)/usr/share/BS/ss/system_manager/rodata
install -m 644 ./PhaseInfo.txt $(DESTDIR)/usr/share/BS/ss/system_manager/rodata
diff --git a/service/system/system_manager/server/src/ss_system_manager.cpp b/service/system/system_manager/server/src/ss_system_manager.cpp
index b767ed7..4f917f9 100755
--- a/service/system/system_manager/server/src/ss_system_manager.cpp
+++ b/service/system/system_manager/server/src/ss_system_manager.cpp
@@ -95,7 +95,7 @@ using namespace std; // NOLINT
static CSystemManager g_oSystemManger;
-#define SS_SM_TEMP_FILE_FOR_STORE_LOGS "/nv/BS/ss/system_manager/rwdata/sm_tempStoreLogs"
+#define SS_SM_TEMP_FILE_FOR_STORE_LOGS "/var/local/lib/basesystem/ss/system_manager/rwdata/sm_tempStoreLogs"
#define TR_USB_PATH "/usr/bin/realtimeUsbLog"
// \brief: public structure that is used for logging by NSLogger.
diff --git a/service/system/system_manager/server/src/ss_system_manager_callbacks.cpp b/service/system/system_manager/server/src/ss_system_manager_callbacks.cpp
index 2e597ce..e126a9b 100755
--- a/service/system/system_manager/server/src/ss_system_manager_callbacks.cpp
+++ b/service/system/system_manager/server/src/ss_system_manager_callbacks.cpp
@@ -2000,7 +2000,7 @@ EFrameworkunifiedStatus CSystemManager::perform_force_reset(HANDLE hApp) {
"NO NAVIDET!! but SendShutdownComp for FactReset");
CALL_AND_LOG_STATUS(send_shutdown_complete_response(hApp)); // LCOV_EXCL_BR_LINE 15: marco defined in ss_templates.h // NOLINT(whitespace/line_length)
sleep(60);
- } else if (access("/nv/BS/ss/system_manager/rwdata/ss_debug", F_OK) == 0) {
+ } else if (access("/var/local/lib/basesystem/ss/system_manager/rwdata/ss_debug", F_OK) == 0) {
fprintf(stderr, "SS_SysManager/%s/NO NAVIDET!! but SendShutdownComp\n", __FUNCTION__);
FRAMEWORKUNIFIEDLOG(ZONE_ERR, __FUNCTION__, "NO NAVIDET!! but SendShutdownComp");
CALL_AND_LOG_STATUS(send_shutdown_complete_response(hApp)); // LCOV_EXCL_BR_LINE 15: marco defined in ss_templates.h // NOLINT(whitespace/line_length)
diff --git a/service/vehicle/positioning/server/src/Sensor/Makefile b/service/vehicle/positioning/server/src/Sensor/Makefile
index 10fb647..fd2251d 100755
--- a/service/vehicle/positioning/server/src/Sensor/Makefile
+++ b/service/vehicle/positioning/server/src/Sensor/Makefile
@@ -173,7 +173,7 @@ CPPFLAGS += -Wformat
LDFLAGS +=
INSTALL = install
-CREATE_DIR = $(DESTDIR)/nv/BS/vs/positioning/rwdata
+CREATE_DIR = $(DESTDIR)/var/local/lib/basesystem/vs/positioning/rwdata
install-data:
$(INSTALL) -d -m 775 $(CREATE_DIR)
diff --git a/service/vehicle/positioning/server/src/Sensor/SensorLog.cpp b/service/vehicle/positioning/server/src/Sensor/SensorLog.cpp
index eed514f..c2b5665 100755
--- a/service/vehicle/positioning/server/src/Sensor/SensorLog.cpp
+++ b/service/vehicle/positioning/server/src/Sensor/SensorLog.cpp
@@ -78,7 +78,7 @@ typedef enum {
#define SENSLOG_SEMAPHO_NAME ("SENSLOG_SEMAPHO") /* Semaphore name(MAX 32Byte) */
-#define SENSLOG_CONFIG_FILE_PATH_1 "/nv/BS/vs/positioning/rwdata/" /* Sensor log-Config filepath-1 */
+#define SENSLOG_CONFIG_FILE_PATH_1 "/var/local/lib/basesystem/vs/positioning/rwdata/" /* Sensor log-Config filepath-1 */
#define SENSLOG_CONFIG_FILE_PATH_2 "/mnt/sda1/" /* Sensor log-Config filepath-2 */
#define SENSLOG_CONFIG_FILE_NAME_SYS "POS_sys_log.cfg" /* Sensor log-Config filename-SYS */
#define SENSLOG_CONFIG_FILE_NAME_GPS "POS_gps_log.cfg" /* Sensor log-Config filename-GPS */
diff --git a/service/vehicle/positioning_base_library/library/Makefile b/service/vehicle/positioning_base_library/library/Makefile
index c0aec5b..b6e4290 100755
--- a/service/vehicle/positioning_base_library/library/Makefile
+++ b/service/vehicle/positioning_base_library/library/Makefile
@@ -80,7 +80,7 @@ LDLIBS += -Wl,-Bdynamic -lev
LDFLAGS += -shared
INSTALL = install
-CREATE_DIR = $(DESTDIR)/nv/BS/vs/positioning_base_library/rwdata
+CREATE_DIR = $(DESTDIR)/var/local/lib/basesystem/vs/positioning_base_library/rwdata
install-data:
$(INSTALL) -d -m 775 $(CREATE_DIR)
diff --git a/service/vehicle/positioning_base_library/library/src/_pbOSCtrl.cpp b/service/vehicle/positioning_base_library/library/src/_pbOSCtrl.cpp
index c38016a..32f9d78 100755
--- a/service/vehicle/positioning_base_library/library/src/_pbOSCtrl.cpp
+++ b/service/vehicle/positioning_base_library/library/src/_pbOSCtrl.cpp
@@ -44,8 +44,8 @@ static u_int8 file_buf[FILE_OUT_LINE][1024];
static u_int16 line_size_buf[FILE_OUT_LINE];
/* Log destination selection (Activate the one you want to output.) */
-#define POS_GPS_R_LOGFILE_PATH "/nv/BS/vs/positioning_base_library/rwdata/Test_Pos_gps_read_data.txt"
-#define POS_GPS_W_LOGFILE_PATH "/nv/BS/vs/positioning_base_library/rwdata/Test_Pos_gps_write_data.txt"
+#define POS_GPS_R_LOGFILE_PATH "/var/local/lib/basesystem/vs/positioning_base_library/rwdata/Test_Pos_gps_read_data.txt"
+#define POS_GPS_W_LOGFILE_PATH "/var/local/lib/basesystem/vs/positioning_base_library/rwdata/Test_Pos_gps_write_data.txt"
#endif /* GPS_FUNC_DEBUG_MSG__CWORD71__FILE */
diff --git a/service/system/logger_service/server/src/ss_logger_util.cpp b/service/system/logger_service/server/src/ss_logger_util.cpp
index 6ac7225..75db3a9 100755
--- a/service/system/logger_service/server/src/ss_logger_util.cpp
+++ b/service/system/logger_service/server/src/ss_logger_util.cpp
@@ -1019,8 +1019,8 @@ EFrameworkunifiedStatus CLoggerUtil::CopyUntyped(std::string f_source,
} else if (0 != S_ISDIR(l_stat.st_mode)) {
l_eStatus = CopyDirectory(f_source, f_destination);
} else if (0 != S_ISLNK(l_stat.st_mode)) {
- // avoid duplicate copy for eErrorEventTypeInterfaceunifiedEmmcLogs: /nv/log/awlog -> /nv/BS/ss/logger_service/rwdata/log2/awlog
- if (f_source.find("/nv/BS/ss/logger_service/rwdata/awlog") == std::string::npos) {
+ // avoid duplicate copy for eErrorEventTypeInterfaceunifiedEmmcLogs: /nv/log/awlog -> /var/local/lib/basesystem/ss/logger_service/rwdata/log2/awlog
+ if (f_source.find("/var/local/lib/basesystem/ss/logger_service/rwdata/awlog") == std::string::npos) {
l_eStatus = CopyDirectory(f_source, f_destination);
}
} else if (0 != S_ISREG(l_stat.st_mode)) {